==> swf-visualizer-0.1.3.tgz: package/src/components/visualizer-info/visualization-container/visualization-room-window/visualization-room-window.jsx <==
import React, { useEffect, useState, useCallback } from 'react';
import { useDispatch, useSelector } from 'react-redux';
import { toast, ToastContainer } from 'react-toastify';
// import { useLoader } from '@services/LoaderContext';

import ThreeScene from '../../ar_tool/components/threejsScene';
import { updateSavedProject } from '@store/actions/saved-project-actions';
import { SceneHolder } from '../../ar_tool/components/sceneHolder';
import RedHeart from '@assets/images/Visualizers-images/red_heart.png';
import CompareIcon from '@assets/images/Visualizers-images/compare-icon.svg';
import './visualization-room-window.scss';

const VisualizationRoomWindow = React.memo(({ showCompare, onFullScreen }) => {
  // const { showLoader, hideLoader } = useLoader();
  const [favoritesCount, setFavoritesCount] = useState('');

  const dispatch = useDispatch();
  const threeSceneHandler = useSelector((state) => state.savedScene);
  const sampleRoomDetails = useSelector((state) => state.savedProjects.sampleRoom);
  const defaultProduct = useSelector((state) => state.savedProjects.defaultProduct);
  const allProducts = useSelector((state) => state.savedProjects.products);

  const addItemOrRemoveIfExists = (array, itemValue) => {
    const existingItemIndex = array.findIndex(item => item.productName === itemValue.productName);
    const configToast = {
      position: "bottom-center",
      hideProgressBar: true,
      theme: "light",
      autoClose: 1000,
      closeOnClick: false,
      className: "toast-fav-message",
      containerId: 'B'
    }

    let info=''
    if (existingItemIndex !== -1) {
      info = 'Removed from comparison list';
      toast.info(info, configToast);
      array.splice(existingItemIndex, 1);
    } else {
      info = 'Added to comparison list';
      toast.info(info, configToast);
      array.push(itemValue);
    }
    return array
  }

  const clickHandler = useCallback(() => {
    const item = { ...defaultProduct, favourites: !defaultProduct?.favourites };
    const clonedScene = {
      modelList: threeSceneHandler?.currentScene?.modelsList.clone(true),
      bgImage: threeSceneHandler?.currentScene?.currentRoomImage,
      currentModel: threeSceneHandler?.currentScene?.currentBlindModel,
      finalVectorArray: threeSceneHandler?.currentScene?.finalVectorArray,
      productName: defaultProduct?.product_name
    };
    SceneHolder.sceneList = addItemOrRemoveIfExists(SceneHolder.sceneList, clonedScene);
    dispatch(updateSavedProject(item));

    if (allProducts) {
      setFavoritesCount(allProducts.filter((item) => item.favourites).length);
    }
  }, [defaultProduct, threeSceneHandler, allProducts]);

  useEffect(() => {

    if (threeSceneHandler.currentScene) {
      // showLoader({content:'loading session...'})
      // threeSceneHandler.currentScene.addEventListener('loadedData', () => hideLoader());
    }
  }, [threeSceneHandler]);

  useEffect(() => {
    if (allProducts) {
      setFavoritesCount(allProducts.filter((item) => item.favourites).length);
    }
  }, [allProducts]);

  return (
    <>
      <ToastContainer containerId="B" />
      <div className='visualizer-img-contaner'>
        {allProducts && (
          <ThreeScene
            width={sampleRoomDetails?.uploadImageDimensions?.width}
            height={sampleRoomDetails?.uploadImageDimensions?.height}
            sampleRoomImage={sampleRoomDetails?.live_path}
            productImage={defaultProduct}
            onFullScreen={onFullScreen}
            uiOptions={true}
          />
        )}

        <div className='top-bar'>
          <a href='/visualization/#' className='expert-btn'>
            Find an Expert
          </a>
          <div className='button-compare'>
            <div className='menu-heart' onClick={clickHandler}>
              {favoritesCount > 0 && <span>{favoritesCount}</span>}
              <img className='img-heart' src={RedHeart} alt='' />
            </div>

            {favoritesCount > 1 && (
              <div className='menu-heart' onClick={showCompare}>
                <img className='img-heart' src={CompareIcon} alt='' />
              </div>
            )}
          </div>
        </div>
      </div>
    </>
  );
});

export default VisualizationRoomWindow;

==> swf-visualizer-0.4.0.tgz: package/src/components/visualizer-info/visualization-container/visualization-room-window/visualization-room-window.jsx <==
import React, { useEffect, useState, useCallback } from 'react';
import { useDispatch, useSelector } from 'react-redux';
import { toast, ToastContainer } from 'react-toastify';
import { useLoader } from '@services/LoaderContext';

import ThreeScene from '../../ar_tool/components/threejsScene';
import { updateSavedProject } from '@store/actions/saved-project-actions';
import { SceneHolder } from '../../ar_tool/components/sceneHolder';
import RedHeart from '../../../../assets/images/Visualizers-images/red_heart.png';
import CompareIcon from '../../../../assets/images/Visualizers-images/compare-icon.svg';
import './visualization-room-window.scss';

const VisualizationRoomWindow = React.memo(({ showCompare, onFullScreen }) => {
  const { showLoader, hideLoader } = useLoader();
  const [favoritesCount, setFavoritesCount] = useState('');

  const dispatch = useDispatch();
  const threeSceneHandler = useSelector((state) => state.savedScene);
  const sampleRoomDetails = useSelector((state) => state.savedProjects.sampleRoom);
  const defaultProduct = useSelector((state) => state.savedProjects.defaultProduct);
  const allProducts = useSelector((state) => state.savedProjects.products);

  const addItemOrRemoveIfExists = (array, itemValue) => {
    const existingItemIndex = array.findIndex(item => item.productName === itemValue.productName);
    const configToast = {
      position: "bottom-center",
      hideProgressBar: true,
      theme: "light",
      autoClose: 1000,
      closeOnClick: false,
      className: "toast-fav-message",
      containerId: 'B'
    }

    let info=''
    if (existingItemIndex !== -1) {
      info = 'Removed from comparison list';
      toast.info(info, configToast);
      array.splice(existingItemIndex, 1);
    } else {
      info = 'Added to comparison list';
      toast.info(info, configToast);
      array.push(itemValue);
    }
    return array
  }

  const clickHandler = useCallback(() => {
    const item = { ...defaultProduct, favourites: !defaultProduct?.favourites };
    const clonedScene = {
      modelList: threeSceneHandler?.currentScene?.modelsList.clone(true),
      bgImage: threeSceneHandler?.currentScene?.currentRoomImage,
      currentModel: threeSceneHandler?.currentScene?.currentBlindModel,
      finalVectorArray: threeSceneHandler?.currentScene?.finalVectorArray,
      productName: defaultProduct?.product_name
    };
    SceneHolder.sceneList = addItemOrRemoveIfExists(SceneHolder.sceneList, clonedScene);
    dispatch(updateSavedProject(item));

    if (allProducts) {
      setFavoritesCount(allProducts.filter((item) => item.favourites).length);
    }
  }, [defaultProduct, threeSceneHandler, allProducts]);

  useEffect(() => {

    if (threeSceneHandler.currentScene) {
      showLoader({content:'loading session...'})
      threeSceneHandler.currentScene.addEventListener('loadedData', () => hideLoader());
    }
  }, [threeSceneHandler]);

  useEffect(() => {
    if (allProducts) {
      setFavoritesCount(allProducts.filter((item) => item.favourites).length);
    }
  }, [allProducts]);

  return (
    <>
      <ToastContainer containerId="B" />
      <div className='visualizer-img-contaner'>
        {allProducts && (
          <ThreeScene
            width={sampleRoomDetails?.uploadImageDimensions?.width}
            height={sampleRoomDetails?.uploadImageDimensions?.height}
            sampleRoomImage={sampleRoomDetails?.live_path}
            productImage={defaultProduct}
            onFullScreen={onFullScreen}
            uiOptions={true}
          />
        )}

        <div className='top-bar'>
          <a href='/visualization/#' className='expert-btn'>
            Find an Expert
          </a>
          <div className='button-compare'>
            <div className='menu-heart' onClick={clickHandler}>
              {favoritesCount > 0 && <span>{favoritesCount}</span>}
              <img className='img-heart' src={RedHeart} alt='' />
            </div>

            {favoritesCount > 1 && (
              <div className='menu-heart' onClick={showCompare}>
                <img className='img-heart' src={CompareIcon} alt='' />
              </div>
            )}
          </div>
        </div>
      </div>
    </>
  );
});

export default VisualizationRoomWindow;
